@@ -19,7 +19,7 @@ typedef enum {
 	E_BOOK_QUERY_TYPE_ANY_FIELD_CONTAINS
 } EBookQueryType;
 
-struct EBookQuery {
+struct _EBookQuery {
 	EBookQueryType type;
 	gint ref_count;
 
@@ -133,7 +133,7 @@ conjoinv (EBookQueryType type,
 /**
  * e_book_query_andv:
  * @q: first #EBookQuery
- * @...: #NULL terminated list of #EBookQuery pointers
+ * @...: %NULL terminated list of #EBookQuery pointers
  *
  * Creates a new #EBookQuery which is the logical AND of the queries specified.
  *
@@ -155,7 +155,7 @@ e_book_query_andv (EBookQuery *q, ...)
 /**
  * e_book_query_orv:
  * @q: first #EBookQuery
- * @...: #NULL terminated list of #EBookQuery pointers
+ * @...: %NULL terminated list of #EBookQuery pointers
  *
  * Creates a new #EBookQuery which is the logical OR of the queries specified.
  *
@@ -375,6 +375,7 @@ e_book_query_unref (EBookQuery *q)
 	case E_BOOK_QUERY_TYPE_FIELD_TEST:
 		g_free (q->query.field_test.field_name);
 		g_free (q->query.field_test.value);
+		g_free (q->query.field_test.locale);
 		break;
 
 	case E_BOOK_QUERY_TYPE_FIELD_EXISTS:
