@@ -2,16 +2,15 @@
 /* Generated data (by glib-mkenums) */
 
 #include "camel-enumtypes.h"
-
 /* enumerations from "camel-enums.h" */
 #include "camel-enums.h"
 
 GType
 camel_authentication_result_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_AUTHENTICATION_ERROR,
 			  "CAMEL_AUTHENTICATION_ERROR",
@@ -24,19 +23,20 @@ camel_authentication_result_get_type (void)
 			  "rejected" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelAuthenticationResult"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_folder_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ CAMEL_FOLDER_HAS_SUMMARY_CAPABILITY,
 			  "CAMEL_FOLDER_HAS_SUMMARY_CAPABILITY",
@@ -58,19 +58,20 @@ camel_folder_flags_get_type (void)
 			  "filter-junk" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("CamelFolderFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_folder_info_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ CAMEL_FOLDER_NOSELECT,
 			  "CAMEL_FOLDER_NOSELECT",
@@ -143,19 +144,20 @@ camel_folder_info_flags_get_type (void)
 			  "flagged" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("CamelFolderInfoFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_mime_filter_to_html_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ CAMEL_MIME_FILTER_TOHTML_PRE,
 			  "CAMEL_MIME_FILTER_TOHTML_PRE",
@@ -192,19 +194,20 @@ camel_mime_filter_to_html_flags_get_type (void)
 			  "quote-citation" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("CamelMimeFilterToHTMLFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_store_info_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ CAMEL_STORE_INFO_FOLDER_NOSELECT,
 			  "CAMEL_STORE_INFO_FOLDER_NOSELECT",
@@ -247,19 +250,20 @@ camel_store_info_flags_get_type (void)
 			  "flagged" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("CamelStoreInfoFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_fetch_headers_type_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_FETCH_HEADERS_BASIC,
 			  "CAMEL_FETCH_HEADERS_BASIC",
@@ -272,19 +276,20 @@ camel_fetch_headers_type_get_type (void)
 			  "all" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelFetchHeadersType"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_junk_status_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_JUNK_STATUS_ERROR,
 			  "CAMEL_JUNK_STATUS_ERROR",
@@ -300,19 +305,20 @@ camel_junk_status_get_type (void)
 			  "message-is-not-junk" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelJunkStatus"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_mime_filter_basic_type_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_MIME_FILTER_BASIC_INVALID,
 			  "CAMEL_MIME_FILTER_BASIC_INVALID",
@@ -337,19 +343,20 @@ camel_mime_filter_basic_type_get_type (void)
 			  "uu-dec" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelMimeFilterBasicType"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_mime_filter_crlf_direction_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_MIME_FILTER_CRLF_ENCODE,
 			  "CAMEL_MIME_FILTER_CRLF_ENCODE",
@@ -359,19 +366,20 @@ camel_mime_filter_crlf_direction_get_type (void)
 			  "decode" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelMimeFilterCRLFDirection"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_mime_filter_crlf_mode_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_MIME_FILTER_CRLF_MODE_CRLF_DOTS,
 			  "CAMEL_MIME_FILTER_CRLF_MODE_CRLF_DOTS",
@@ -381,19 +389,20 @@ camel_mime_filter_crlf_mode_get_type (void)
 			  "only" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelMimeFilterCRLFMode"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_mime_filter_gzip_mode_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_MIME_FILTER_GZIP_MODE_ZIP,
 			  "CAMEL_MIME_FILTER_GZIP_MODE_ZIP",
@@ -403,19 +412,20 @@ camel_mime_filter_gzip_mode_get_type (void)
 			  "unzip" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelMimeFilterGZipMode"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_mime_filter_yenc_direction_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_MIME_FILTER_YENC_DIRECTION_ENCODE,
 			  "CAMEL_MIME_FILTER_YENC_DIRECTION_ENCODE",
@@ -425,19 +435,20 @@ camel_mime_filter_yenc_direction_get_type (void)
 			  "decode" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelMimeFilterYencDirection"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_network_security_method_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_NETWORK_SECURITY_METHOD_NONE,
 			  "CAMEL_NETWORK_SECURITY_METHOD_NONE",
@@ -450,19 +461,20 @@ camel_network_security_method_get_type (void)
 			  "starttls-on-standard-port" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelNetworkSecurityMethod"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_provider_conf_type_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_PROVIDER_CONF_END,
 			  "CAMEL_PROVIDER_CONF_END",
@@ -493,19 +505,20 @@ camel_provider_conf_type_get_type (void)
 			  "options" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelProviderConfType"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_provider_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ CAMEL_PROVIDER_IS_REMOTE,
 			  "CAMEL_PROVIDER_IS_REMOTE",
@@ -548,19 +561,20 @@ camel_provider_flags_get_type (void)
 			  "supports-purge-message-cache" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("CamelProviderFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_provider_type_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_PROVIDER_STORE,
 			  "CAMEL_PROVIDER_STORE",
@@ -570,19 +584,20 @@ camel_provider_type_get_type (void)
 			  "transport" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelProviderType"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_sasl_anon_trace_type_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_SASL_ANON_TRACE_EMAIL,
 			  "CAMEL_SASL_ANON_TRACE_EMAIL",
@@ -595,19 +610,20 @@ camel_sasl_anon_trace_type_get_type (void)
 			  "empty" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelSaslAnonTraceType"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_service_connection_status_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_SERVICE_DISCONNECTED,
 			  "CAMEL_SERVICE_DISCONNECTED",
@@ -623,19 +639,20 @@ camel_service_connection_status_get_type (void)
 			  "disconnecting" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelServiceConnectionStatus"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_session_alert_type_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_SESSION_ALERT_INFO,
 			  "CAMEL_SESSION_ALERT_INFO",
@@ -648,19 +665,20 @@ camel_session_alert_type_get_type (void)
 			  "error" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelSessionAlertType"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_sort_type_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_SORT_ASCENDING,
 			  "CAMEL_SORT_ASCENDING",
@@ -670,19 +688,20 @@ camel_sort_type_get_type (void)
 			  "descending" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelSortType"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_store_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ CAMEL_STORE_VTRASH,
 			  "CAMEL_STORE_VTRASH",
@@ -707,19 +726,20 @@ camel_store_flags_get_type (void)
 			  "use-cache-dir" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("CamelStoreFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_store_get_folder_info_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ CAMEL_STORE_FOLDER_INFO_FAST,
 			  "CAMEL_STORE_FOLDER_INFO_FAST",
@@ -738,19 +758,20 @@ camel_store_get_folder_info_flags_get_type (void)
 			  "subscription-list" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("CamelStoreGetFolderInfoFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_store_permission_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ CAMEL_STORE_READ,
 			  "CAMEL_STORE_READ",
@@ -760,19 +781,20 @@ camel_store_permission_flags_get_type (void)
 			  "write" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("CamelStorePermissionFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_tcp_stream_ssl_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ CAMEL_TCP_STREAM_SSL_ENABLE_SSL2,
 			  "CAMEL_TCP_STREAM_SSL_ENABLE_SSL2",
@@ -785,19 +807,20 @@ camel_tcp_stream_ssl_flags_get_type (void)
 			  "tls" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("CamelTcpStreamSSLFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_transfer_encoding_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_TRANSFER_ENCODING_DEFAULT,
 			  "CAMEL_TRANSFER_ENCODING_DEFAULT",
@@ -825,19 +848,20 @@ camel_transfer_encoding_get_type (void)
 			  "num-encodings" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelTransferEncoding"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 camel_stream_vfs_open_method_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ CAMEL_STREAM_VFS_CREATE,
 			  "CAMEL_STREAM_VFS_CREATE",
@@ -850,11 +874,12 @@ camel_stream_vfs_open_method_get_type (void)
 			  "read" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("CamelStreamVFSOpenMethod"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 
