@@ -581,6 +581,8 @@ gboolean
 camel_imapx_command_set_error_if_failed (CamelIMAPXCommand *ic,
                                          GError **error)
 {
+	CamelIMAPXJob *job;
+
 	g_return_val_if_fail (CAMEL_IS_IMAPX_COMMAND (ic), FALSE);
 
 	if (ic->status != NULL && ic->status->result != IMAPX_OK) {
@@ -595,6 +597,10 @@ camel_imapx_command_set_error_if_failed (CamelIMAPXCommand *ic,
 		return TRUE;
 	}
 
+	job = camel_imapx_command_get_job (ic);
+	if (job && g_cancellable_set_error_if_cancelled (camel_imapx_job_get_cancellable (job), error))
+		return TRUE;
+
 	return FALSE;
 }
 
