@@ -300,8 +300,8 @@ session_get_property (GObject *object,
 			return;
 
 		case PROP_MAIN_CONTEXT:
-			g_value_set_boxed (
-				value, camel_session_get_main_context (
+			g_value_take_boxed (
+				value, camel_session_ref_main_context (
 				CAMEL_SESSION (object)));
 			return;
 
@@ -772,7 +772,8 @@ camel_session_class_init (CamelSessionClass *class)
 		g_param_spec_boxed (
 			"main-context",
 			"Main Context",
-			"The GMainContext used for signal emissions",
+			"The main loop context on "
+			"which to attach event sources",
 			G_TYPE_MAIN_CONTEXT,
 			G_PARAM_READABLE |
 			G_PARAM_STATIC_STRINGS));
@@ -871,13 +872,14 @@ camel_session_init (CamelSession *session)
  * camel_session_get_main_context:
  * @session: a #CamelSession
  *
- * Returns the #GMainContext from which signals are emitted.  This
- * was the thread-default #GMainContext for the thread where @session
- * was instantiated.
+ * Returns the #GMainContext on which event sources for @session are to
+ * be attached.
  *
- * Returns: the #GMainContext for signal emissions
+ * Returns: a #GMainContext
  *
  * Since: 3.6
+ *
+ * Deprecated: 3.8: Use camel_session_ref_main_context() instead.
  **/
 GMainContext *
 camel_session_get_main_context (CamelSession *session)
@@ -887,6 +889,25 @@ camel_session_get_main_context (CamelSession *session)
 	return session->priv->main_context;
 }
 
+/**
+ * camel_session_ref_main_context:
+ * @session: a #CamelSession
+ *
+ * Returns the #GMainContext on which event sources for @session are to
+ * be attached.
+ *
+ * Returns: a #GMainContext
+ *
+ * Since: 3.8
+ **/
+GMainContext *
+camel_session_ref_main_context (CamelSession *session)
+{
+	g_return_val_if_fail (CAMEL_IS_SESSION (session), NULL);
+
+	return g_main_context_ref (session->priv->main_context);
+}
+
 /**
  * camel_session_get_user_data_dir:
  * @session: a #CamelSession
@@ -1395,10 +1416,10 @@ camel_session_build_password_prompt (const gchar *type,
 	user_markup = g_markup_printf_escaped ("<b>%s</b>", user);
 	host_markup = g_markup_printf_escaped ("<b>%s</b>", host);
 
-	/* Translators: The first argument is the account type
-	 * (e.g. "IMAP"), the second is the user name, and the
-	 * third is the host name. */
 	prompt = g_strdup_printf (
+		/* Translators: The first argument is the account type
+		 * (e.g. "IMAP"), the second is the user name, and the
+		 * third is the host name. */
 		_("Please enter the %s password for %s on host %s."),
 		type, user_markup, host_markup);
 
@@ -1564,7 +1585,7 @@ camel_session_idle_add (CamelSession *session,
 	g_return_val_if_fail (CAMEL_IS_SESSION (session), 0);
 	g_return_val_if_fail (function != NULL, 0);
 
-	main_context = camel_session_get_main_context (session);
+	main_context = camel_session_ref_main_context (session);
 
 	source = g_idle_source_new ();
 
@@ -1577,6 +1598,8 @@ camel_session_idle_add (CamelSession *session,
 
 	g_source_unref (source);
 
+	g_main_context_unref (main_context);
+
 	return source_id;
 }
 
