@@ -2,16 +2,15 @@
 /* Generated data (by glib-mkenums) */
 
 #include "e-backend-enumtypes.h"
-
 /* enumerations from "e-backend-enums.h" */
 #include "e-backend-enums.h"
 
 GType
 e_authentication_session_result_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ E_AUTHENTICATION_SESSION_ERROR,
 			  "E_AUTHENTICATION_SESSION_ERROR",
@@ -24,19 +23,20 @@ e_authentication_session_result_get_type (void)
 			  "dismissed" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("EAuthenticationSessionResult"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 e_dbus_server_exit_code_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GEnumValue values[] = {
 			{ E_DBUS_SERVER_EXIT_NONE,
 			  "E_DBUS_SERVER_EXIT_NONE",
@@ -49,19 +49,20 @@ e_dbus_server_exit_code_get_type (void)
 			  "reload" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_enum_register_static (
+		GType the_type = g_enum_register_static (
 			g_intern_static_string ("EDBusServerExitCode"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 GType
 e_source_permission_flags_get_type (void)
 {
-	static GType the_type = 0;
-	
-	if (the_type == 0) {
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
 		static const GFlagsValue values[] = {
 			{ E_SOURCE_PERMISSION_NONE,
 			  "E_SOURCE_PERMISSION_NONE",
@@ -74,11 +75,12 @@ e_source_permission_flags_get_type (void)
 			  "removable" },
 			{ 0, NULL, NULL }
 		};
-		the_type = g_flags_register_static (
+		GType the_type = g_flags_register_static (
 			g_intern_static_string ("ESourcePermissionFlags"),
 			values);
+		g_once_init_leave (&the_type__volatile, the_type);
 	}
-	return the_type;
+	return the_type__volatile;
 }
 
 
